@@ -145,6 +145,31 @@ class CControllerPopupItemTestEdit extends CControllerPopupItemTest {
 		$texts_support_lld_macros = [];
 		$supported_macros = [];
 		foreach (array_keys(array_intersect_key($inputs, $this->macros_by_item_props)) as $field) {
+			// Special processing for calculated item formula.
+			if ($field === 'params_f') {
+				$expression_data = new CTriggerExpression(['calculated' => true, 'lldmacros' => $support_lldmacros]);
+
+				if (($result = $expression_data->parse($inputs[$field])) !== false) {
+					foreach ($result->getTokens() as $token) {
+						switch ($token['type']) {
+							case CTriggerExprParserResult::TOKEN_TYPE_USER_MACRO:
+								$texts_support_user_macros[] = $token['value'];
+								break;
+
+							case CTriggerExprParserResult::TOKEN_TYPE_LLD_MACRO:
+								$texts_support_lld_macros[] = $token['value'];
+								break;
+
+							case CTriggerExprParserResult::TOKEN_TYPE_STRING:
+								$texts_support_user_macros[] = $token['data']['string'];
+								$texts_support_lld_macros[] = $token['data']['string'];
+								break;
+						}
+					}
+				}
+				continue;
+			}
+
 			$macros = $this->macros_by_item_props[$field];
 			unset($macros['support_lld_macros'], $macros['support_user_macros']);
 
@@ -267,9 +292,11 @@ class CControllerPopupItemTestEdit extends CControllerPopupItemTest {
 			'inputs' => $inputs,
 			'proxies' => in_array($this->item_type, $this->items_support_proxy) ? $this->getHostProxies() : [],
 			'proxies_enabled' => in_array($this->item_type, $this->items_support_proxy),
-			'interface_address_enabled' => in_array($this->item_type, $this->items_require_interface),
-			'interface_port_enabled' => (in_array($this->item_type, $this->items_require_interface)
-				&& $this->item_type != ITEM_TYPE_SIMPLE
+			'interface_address_enabled' => (array_key_exists($this->item_type, $this->items_require_interface)
+				&& $this->items_require_interface[$this->item_type]['address']
+			),
+			'interface_port_enabled' => (array_key_exists($this->item_type, $this->items_require_interface)
+				&& $this->items_require_interface[$this->item_type]['port']
 			),
 			'user' => [
 				'debug_mode' => $this->getDebugMode()
