@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ class CControllerWidgetGraphView extends CControllerWidget {
 		$profileIdx = 'web.dashbrd.filter';
 		$profileIdx2 = $this->getInput('dashboardid', 0);
 		$unavailable_object = false;
-		$header_label = '';
+		$header_label = $this->getDefaultHeader();
 
 		if ($fields['source_type'] == ZBX_WIDGET_FIELD_RESOURCE_GRAPH && $fields['graphid']) {
 			$resource_type = SCREEN_RESOURCE_GRAPH;
@@ -346,7 +346,12 @@ class CControllerWidgetGraphView extends CControllerWidget {
 			$time_control_data['src'] = $graph_src->getUrl();
 
 			if ($fields['source_type'] == ZBX_WIDGET_FIELD_RESOURCE_GRAPH) {
-				$item_graph_url = (new CUrl('charts.php'))->setArgument('graphid', $resourceid);
+				$item_graph_url = (new CUrl('zabbix.php'))
+					->setArgument('action', 'charts.view')
+					->setArgument('view_as', HISTORY_GRAPH)
+					->setArgument('filter_search_type', ZBX_SEARCH_TYPE_STRICT)
+					->setArgument('filter_graphids', [$resourceid])
+					->setArgument('filter_set', '1');
 			}
 			else {
 				$item_graph_url = (new CUrl('history.php'))->setArgument('itemids', [$resourceid]);
