@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 $table = (new CTableInfo())->setNoDataMessage(_('No graphs added.'));
 
 foreach ($data['graphs'] as $graph) {
@@ -26,7 +30,13 @@ foreach ($data['graphs'] as $graph) {
 		? (new CUrl('history.php'))
 			->setArgument('action', HISTORY_GRAPH)
 			->setArgument('itemids', [$graph['itemid']])
-		: (new CUrl('charts.php'))->setArgument('graphid', $graph['graphid']);
+		: (new CUrl('zabbix.php'))
+			->setArgument('action', 'charts.view')
+			->setArgument('view_as', HISTORY_GRAPH)
+			->setArgument('filter_search_type', ZBX_SEARCH_TYPE_STRICT)
+			->setArgument('filter_graphids', [$graph['graphid']])
+			->setArgument('filter_set', '1');
+
 	$on_click = $graph['simple']
 		? "rm4favorites('itemid','".$graph['itemid']."')"
 		: "rm4favorites('graphid','".$graph['graphid']."')";
@@ -55,4 +65,4 @@ if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
 	$output['debug'] = CProfiler::getInstance()->make()->toString();
 }
 
-echo (new CJson())->encode($output);
+echo json_encode($output);
