@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ class CItem extends CItemGeneral {
 		ZBX_PREPROC_VALIDATE_RANGE, ZBX_PREPROC_VALIDATE_REGEX, ZBX_PREPROC_VALIDATE_NOT_REGEX,
 		ZBX_PREPROC_ERROR_FIELD_JSON, ZBX_PREPROC_ERROR_FIELD_XML, ZBX_PREPROC_ERROR_FIELD_REGEX,
 		ZBX_PREPROC_THROTTLE_VALUE, ZBX_PREPROC_THROTTLE_TIMED_VALUE, ZBX_PREPROC_SCRIPT,
-		ZBX_PREPROC_PROMETHEUS_PATTERN, ZBX_PREPROC_PROMETHEUS_TO_JSON, ZBX_PREPROC_CSV_TO_JSON
+		ZBX_PREPROC_PROMETHEUS_PATTERN, ZBX_PREPROC_PROMETHEUS_TO_JSON, ZBX_PREPROC_CSV_TO_JSON, ZBX_PREPROC_STR_REPLACE
 	];
 
 	public function __construct() {
@@ -389,7 +389,7 @@ class CItem extends CItemGeneral {
 
 		$sqlParts = $this->applyQueryOutputOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
-		$res = DBselect($this->createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
+		$res = DBselect(self::createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 		while ($item = DBfetch($res)) {
 			if (!$options['countOutput']) {
 				$result[$item['itemid']] = $item;
@@ -420,18 +420,17 @@ class CItem extends CItemGeneral {
 		}
 
 		// Decode ITEM_TYPE_HTTPAGENT encoded fields.
-		$json = new CJson();
-
 		foreach ($result as &$item) {
 			if (array_key_exists('query_fields', $item)) {
-				$query_fields = ($item['query_fields'] !== '') ? $json->decode($item['query_fields'], true) : [];
-				$item['query_fields'] = $json->hasError() ? [] : $query_fields;
+				$query_fields = ($item['query_fields'] !== '') ? json_decode($item['query_fields'], true) : [];
+				$item['query_fields'] = json_last_error() ? [] : $query_fields;
 			}
 
 			if (array_key_exists('headers', $item)) {
 				$item['headers'] = $this->headersStringToArray($item['headers']);
 			}
 		}
+		unset($item);
 
 		return $result;
 	}
@@ -457,12 +456,10 @@ class CItem extends CItemGeneral {
 
 		$this->validateDependentItems($items);
 
-		$json = new CJson();
-
 		foreach ($items as &$item) {
 			if ($item['type'] == ITEM_TYPE_HTTPAGENT) {
 				if (array_key_exists('query_fields', $item)) {
-					$item['query_fields'] = $item['query_fields'] ? $json->encode($item['query_fields']) : '';
+					$item['query_fields'] = $item['query_fields'] ? json_encode($item['query_fields']) : '';
 				}
 
 				if (array_key_exists('headers', $item)) {
@@ -600,7 +597,7 @@ class CItem extends CItemGeneral {
 	 *
 	 * @param array $items
 	 *
-	 * @return boolean
+	 * @return array
 	 */
 	public function update($items) {
 		$items = zbx_toArray($items);
@@ -645,8 +642,6 @@ class CItem extends CItemGeneral {
 			]
 		];
 
-		$json = new CJson();
-
 		foreach ($items as &$item) {
 			$type_change = ($item['type'] != $db_items[$item['itemid']]['type']);
 
@@ -681,7 +676,7 @@ class CItem extends CItemGeneral {
 				}
 
 				if (array_key_exists('query_fields', $item) && is_array($item['query_fields'])) {
-					$item['query_fields'] = $item['query_fields'] ? $json->encode($item['query_fields']) : '';
+					$item['query_fields'] = $item['query_fields'] ? json_encode($item['query_fields']) : '';
 				}
 
 				if (array_key_exists('headers', $item) && is_array($item['headers'])) {
@@ -780,15 +775,13 @@ class CItem extends CItemGeneral {
 			'preservekeys' => true
 		]);
 
-		$json = new CJson();
-
 		foreach ($tpl_items as &$tpl_item) {
 			$tpl_item['applications'] = zbx_objectValues($tpl_item['applications'], 'applicationid');
 
 			if ($tpl_item['type'] == ITEM_TYPE_HTTPAGENT) {
 				if (array_key_exists('query_fields', $tpl_item) && is_array($tpl_item['query_fields'])) {
 					$tpl_item['query_fields'] = $tpl_item['query_fields']
-						? $json->encode($tpl_item['query_fields'])
+						? json_encode($tpl_item['query_fields'])
 						: '';
 				}
 
@@ -1200,12 +1193,12 @@ class CItem extends CItemGeneral {
 	protected function applyQueryOutputOptions($tableName, $tableAlias, array $options, array $sqlParts) {
 		$sqlParts = parent::applyQueryOutputOptions($tableName, $tableAlias, $options, $sqlParts);
 
-		if ($this->outputIsRequested('state', $options['output'])
-				|| $this->outputIsRequested('error', $options['output'])
+		if ((!$options['countOutput'] && ($this->outputIsRequested('state', $options['output'])
+				|| $this->outputIsRequested('error', $options['output'])))
 				|| (is_array($options['search']) && array_key_exists('error', $options['search']))
 				|| (is_array($options['filter']) && array_key_exists('state', $options['filter']))) {
-			$sqlParts['left_join']['item_rtdata'] = ['from' => 'item_rtdata ir', 'on' => 'ir.itemid=i.itemid'];
-			$sqlParts['left_table'] = $tableName;
+			$sqlParts['left_join'][] = ['alias' => 'ir', 'table' => 'item_rtdata', 'using' => 'itemid'];
+			$sqlParts['left_table'] = ['alias' => $this->tableAlias, 'table' => $this->tableName];
 		}
 
 		if (!$options['countOutput']) {
@@ -1214,7 +1207,7 @@ class CItem extends CItemGeneral {
 			}
 			if ($this->outputIsRequested('error', $options['output'])) {
 				/*
-				 * SQL func COALESCE use for template items because they dont have record
+				 * SQL func COALESCE use for template items because they don't have record
 				 * in item_rtdata table and DBFetch convert null to '0'
 				 */
 				$sqlParts = $this->addQuerySelect(dbConditionCoalesce('ir.error', '', 'error'), $sqlParts);
