@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -40,10 +40,38 @@ class CScreenDataOverview extends CScreenBase {
 				->addItem([_('Group'), ':', SPACE, $groups[0]['name']])
 		]))->addClass(ZBX_STYLE_DASHBRD_WIDGET_HEAD);
 
-		$table = getItemsDataOverview((array) $groupid, $this->screenitem['application'], $this->screenitem['style']);
+		$data = [];
+		if ($this->screenitem['style'] == STYLE_TOP) {
+			list($db_items, $db_hosts, $items_by_name, $has_hidden_data) = getDataOverviewTop((array) $groupid, null,
+				$this->screenitem['application']
+			);
+
+			$data['visible_items'] = getDataOverviewCellData($db_hosts, $db_items, $items_by_name,
+				ZBX_PROBLEM_SUPPRESSED_FALSE
+			);
+			$data['db_hosts'] = $db_hosts;
+			$data['items_by_name'] = $items_by_name;
+			$data['has_hidden_data'] = $has_hidden_data;
+
+			$table = new CPartial('dataoverview.table.top', $data);
+		}
+		else {
+			list($db_items, $db_hosts, $items_by_name, $has_hidden_data) = getDataOverviewLeft((array) $groupid, null,
+				$this->screenitem['application']
+			);
+
+			$data['visible_items'] = getDataOverviewCellData($db_hosts, $db_items, $items_by_name,
+				ZBX_PROBLEM_SUPPRESSED_FALSE
+			);
+			$data['db_hosts'] = $db_hosts;
+			$data['items_by_name'] = $items_by_name;
+			$data['has_hidden_data'] = $has_hidden_data;
+
+			$table = new CPartial('dataoverview.table.left', $data);
+		}
 
 		$footer = (new CList())
-			->addItem(_s('Updated: %s', zbx_date2str(TIME_FORMAT_SECONDS)))
+			->addItem(_s('Updated: %1$s', zbx_date2str(TIME_FORMAT_SECONDS)))
 			->addClass(ZBX_STYLE_DASHBRD_WIDGET_FOOT);
 
 		return $this->getOutput(new CUiWidget(uniqid(), [$header, $table, $footer]));
