@@ -159,7 +159,6 @@ class CScreenProblem extends CScreenBase {
 	 *                                                           TRIGGERS_OPTION_(RECENT|IN)_PROBLEM
 	 * @param int    $filter['age']                   (optional) usable together with 'age_state' and only for
 	 *                                                           TRIGGERS_OPTION_(RECENT|IN)_PROBLEM
-	 * @param int    $filter['severity']              (optional)
 	 * @param array  $filter['severities']            (optional)
 	 * @param int    $filter['unacknowledged']        (optional)
 	 * @param array  $filter['tags']                  (optional)
@@ -278,9 +277,6 @@ class CScreenProblem extends CScreenBase {
 					$options['time_from'] = time() - $filter['age'] * SEC_PER_DAY + 1;
 				}
 			}
-			if (array_key_exists('severity', $filter) && $filter['severity'] != TRIGGER_SEVERITY_NOT_CLASSIFIED) {
-				$options['severities'] = range($filter['severity'], TRIGGER_SEVERITY_COUNT - 1);
-			}
 			if (array_key_exists('severities', $filter)) {
 				$filter_severities = implode(',', $filter['severities']);
 				$all_severities = implode(',', range(TRIGGER_SEVERITY_NOT_CLASSIFIED, TRIGGER_SEVERITY_COUNT - 1));
@@ -790,7 +786,7 @@ class CScreenProblem extends CScreenBase {
 		$data = self::sortData($data, $this->config, $this->data['sort'], $this->data['sortorder']);
 
 		if ($this->data['action'] === 'problem.view') {
-			$paging = getPagingLine($data['problems'], ZBX_SORT_UP, clone $url);
+			$paging = CPagerHelper::paginate($this->page, $data['problems'], ZBX_SORT_UP, $url);
 		}
 
 		$data = self::makeData($data, $this->data['filter'], true);
@@ -817,22 +813,15 @@ class CScreenProblem extends CScreenBase {
 			$triggers_hosts = getTriggersHostsList($data['triggers']);
 		}
 
-
 		$show_opdata = $this->data['filter']['compact_view']
 			? OPERATIONAL_DATA_SHOW_NONE
 			: $this->data['filter']['show_opdata'];
 
 		if ($this->data['action'] === 'problem.view') {
-			$url_form = clone $url;
-
 			$form = (new CForm('post', 'zabbix.php'))
+				->setId('problem_form')
 				->setName('problem')
-				->cleanItems()
-				->addVar('backurl',
-					$url_form
-						->setArgument('uncheck', '1')
-						->getUrl()
-				);
+				->cleanItems();
 
 			$header_check_box = (new CColHeader(
 				(new CCheckBox('all_eventids'))
@@ -843,9 +832,7 @@ class CScreenProblem extends CScreenBase {
 				? $header_check_box->addStyle('width: 20px;')
 				: $header_check_box->addClass(ZBX_STYLE_CELL_WIDTH);
 
-			$link = $url
-				->setArgument('page', $this->data['page'])
-				->getUrl();
+			$link = $url->getUrl();
 
 			$show_timeline = ($this->data['sort'] === 'clock' && !$this->data['filter']['compact_view']
 				&& $this->data['filter']['show_timeline']);
@@ -957,11 +944,6 @@ class CScreenProblem extends CScreenBase {
 				$dependencies = getTriggerDependencies($data['triggers']);
 			}
 
-			// Create link to Problem update page.
-			$problem_update_url = (new CUrl('zabbix.php'))
-				->setArgument('action', 'acknowledge.edit')
-				->setArgument('backurl', $url->setArgument('uncheck', '1')->getUrl());
-
 			// Add problems to table.
 			foreach ($data['problems'] as $eventid => $problem) {
 				$trigger = $data['triggers'][$problem['objectid']];
@@ -1011,12 +993,11 @@ class CScreenProblem extends CScreenBase {
 					$value_clock = $in_closing ? time() : $problem['clock'];
 				}
 
+				$is_acknowledged = ($problem['acknowledged'] == EVENT_ACKNOWLEDGED);
 				$cell_status = new CSpan($value_str);
 
 				// Add colors and blinking to span depending on configuration and trigger parameters.
-				addTriggerValueStyle($cell_status, $value, $value_clock,
-					$problem['acknowledged'] == EVENT_ACKNOWLEDGED
-				);
+				addTriggerValueStyle($cell_status, $value, $value_clock, $is_acknowledged);
 
 				// Info.
 				$info_icons = [];
@@ -1060,8 +1041,8 @@ class CScreenProblem extends CScreenBase {
 					->setMenuPopup(CMenuPopupHelper::getTrigger($trigger['triggerid'], $problem['eventid']));
 
 				$opdata = null;
-				if ($show_opdata != OPERATIONAL_DATA_SHOW_NONE) {
 
+				if ($show_opdata != OPERATIONAL_DATA_SHOW_NONE) {
 					if ($trigger['opdata'] === '') {
 						if ($show_opdata == OPERATIONAL_DATA_SHOW_SEPARATELY) {
 							$opdata = (new CCol(self::getLatestValues($trigger['items'])))->addClass('latest-values');
@@ -1098,11 +1079,11 @@ class CScreenProblem extends CScreenBase {
 					$description[] = BR();
 
 					if ($trigger['recovery_mode'] == ZBX_RECOVERY_MODE_RECOVERY_EXPRESSION) {
-						$description[] = [_('Problem'), ': ', $trigger['expression_html'], BR()];
-						$description[] = [_('Recovery'), ': ', $trigger['recovery_expression_html']];
+						$description[] = [_('Problem'), ': ', (new CDiv($trigger['expression_html']))->addClass(ZBX_STYLE_WORDWRAP), BR()];
+						$description[] = [_('Recovery'), ': ', (new CDiv($trigger['recovery_expression_html']))->addClass(ZBX_STYLE_WORDWRAP)];
 					}
 					else {
-						$description[] = $trigger['expression_html'];
+						$description[] = (new CDiv($trigger['expression_html']))->addClass(ZBX_STYLE_WORDWRAP);
 					}
 				}
 
@@ -1129,11 +1110,10 @@ class CScreenProblem extends CScreenBase {
 				}
 
 				// Create acknowledge link.
-				$problem_update_url->setArgument('eventids', [$problem['eventid']]);
-				$acknowledged = ($problem['acknowledged'] == EVENT_ACKNOWLEDGED);
-				$problem_update_link = (new CLink($acknowledged ? _('Yes') : _('No'), $problem_update_url->getUrl()))
-					->addClass($acknowledged ? ZBX_STYLE_GREEN : ZBX_STYLE_RED)
-					->addClass(ZBX_STYLE_LINK_ALT);
+				$problem_update_link = (new CLink($is_acknowledged ? _('Yes') : _('No')))
+					->addClass($is_acknowledged ? ZBX_STYLE_GREEN : ZBX_STYLE_RED)
+					->addClass(ZBX_STYLE_LINK_ALT)
+					->onClick('acknowledgePopUp('.json_encode(['eventids' => [$problem['eventid']]]).', this);');
 
 				// Add table row.
 				$table->addRow(array_merge($row, [
@@ -1164,7 +1144,7 @@ class CScreenProblem extends CScreenBase {
 			}
 
 			$footer = new CActionButtonList('action', 'eventids', [
-				'acknowledge.edit' => ['name' => _('Mass update')]
+				'popup.acknowledge.edit' => ['name' => _('Mass update')]
 			], 'problem');
 
 			return $this->getOutput($form->addItem([$table, $paging, $footer]), true, $this->data);
