@@ -70,6 +70,9 @@ class CApiInputValidator {
 	 */
 	private static function validateData($rule, &$data, $path, &$error, array $parent_data = null) {
 		switch ($rule['type']) {
+			case API_CALC_FORMULA:
+				return self::validateCalcFormula($rule, $data, $path, $error);
+
 			case API_COLOR:
 				return self::validateColor($rule, $data, $path, $error);
 
@@ -188,6 +191,7 @@ class CApiInputValidator {
 	 */
 	private static function validateDataUniqueness($rule, &$data, $path, &$error) {
 		switch ($rule['type']) {
+			case API_CALC_FORMULA:
 			case API_COLOR:
 			case API_MULTIPLE:
 			case API_STRING_UTF8:
@@ -272,6 +276,33 @@ class CApiInputValidator {
 		return true;
 	}
 
+	/**
+	 * Calculated item formula validator.
+	 *
+	 * @param array  $rule
+	 * @param int    $rule['flags']   (optional) API_ALLOW_LLD_MACRO
+	 * @param mixed  $data
+	 * @param string $path
+	 * @param string $error
+	 *
+	 * @return bool
+	 */
+	private static function validateCalcFormula($rule, &$data, $path, &$error) {
+		$flags = array_key_exists('flags', $rule) ? $rule['flags'] : 0x00;
+
+		if (self::checkStringUtf8(API_NOT_EMPTY, $data, $path, $error) === false) {
+			return false;
+		}
+
+		$expression_data = new CTriggerExpression(['calculated' => true, 'lldmacros' => ($flags & API_ALLOW_LLD_MACRO)]);
+		if (!$expression_data->parse($data)) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, $expression_data->error);
+			return false;
+		}
+
+		return true;
+	}
+
 	/**
 	 * Color validator.
 	 *
@@ -441,12 +472,12 @@ class CApiInputValidator {
 			return true;
 		}
 
-		if ((!is_int($data) && !is_string($data)) || preg_match('/^\-?[0-9]+$/', strval($data)) !== 1) {
+		if ((!is_int($data) && !is_string($data)) || !preg_match('/^'.ZBX_PREG_INT.'$/', strval($data))) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('an integer is expected'));
 			return false;
 		}
 
-		if (bccomp($data, ZBX_MIN_INT32) < 0 || bccomp($data, ZBX_MAX_INT32) > 0) {
+		if ($data < ZBX_MIN_INT32 || $data > ZBX_MAX_INT32) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is too large'));
 			return false;
 		}
@@ -568,14 +599,31 @@ class CApiInputValidator {
 			return true;
 		}
 
-		if (is_int($data) || (is_string($data) && preg_match('/^-?[0-9]*\.?[0-9]+([eE][+-]?[0-9]+)?$/', $data) === 1)) {
-			$data = (float) $data;
+		if (is_int($data) || is_float($data)) {
+			$value = (float) $data;
 		}
-		elseif (!is_float($data)) {
+		elseif (is_string($data)) {
+			$number_parser = new CNumberParser();
+
+			if ($number_parser->parse($data) == CParser::PARSE_SUCCESS) {
+				$value = (float) $number_parser->getMatch();
+			}
+			else {
+				$value = NAN;
+			}
+		}
+		else {
+			$value = NAN;
+		}
+
+		if (is_nan($value)) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a floating point value is expected'));
+
 			return false;
 		}
 
+		$data = $value;
+
 		return true;
 	}
 
@@ -774,6 +822,7 @@ class CApiInputValidator {
 	 * Boolean validator.
 	 *
 	 * @param array  $rule
+	 * @param int    $rule['flags']  (optional) API_ALLOW_NULL
 	 * @param mixed  $data
 	 * @param string $path
 	 * @param string $error
@@ -781,6 +830,12 @@ class CApiInputValidator {
 	 * @return bool
 	 */
 	private static function validateBoolean($rule, &$data, $path, &$error) {
+		$flags = array_key_exists('flags', $rule) ? $rule['flags'] : 0x00;
+
+		if (($flags & API_ALLOW_NULL) && $data === null) {
+			return true;
+		}
+
 		if (!is_bool($data)) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a boolean is expected'));
 			return false;
@@ -1057,7 +1112,7 @@ class CApiInputValidator {
 	 * Array of objects validator.
 	 *
 	 * @param array  $rule
-	 * @param int    $rule['flags']   (optional) API_NOT_EMPTY, API_ALLOW_NULL, API_NORMALIZE
+	 * @param int    $rule['flags']   (optional) API_NOT_EMPTY, API_ALLOW_NULL, API_NORMALIZE, API_PRESERVE_KEYS
 	 * @param array  $rule['fields']
 	 * @param mixed  $data
 	 * @param string $path
@@ -1090,7 +1145,9 @@ class CApiInputValidator {
 			}
 		}
 
-		$data = array_values($data);
+		if (!($flags & API_PRESERVE_KEYS)) {
+			$data = array_values($data);
+		}
 
 		foreach ($data as $index => &$value) {
 			$subpath = ($path === '/' ? $path : $path.'/').($index + 1);
@@ -1205,6 +1262,8 @@ class CApiInputValidator {
 	 * @return bool
 	 */
 	private static function validateNumeric($rule, &$data, $path, &$error) {
+		global $DB;
+
 		$flags = array_key_exists('flags', $rule) ? $rule['flags'] : 0x00;
 
 		if (is_int($data)) {
@@ -1217,6 +1276,7 @@ class CApiInputValidator {
 
 		if (array_key_exists('length', $rule) && mb_strlen($data) > $rule['length']) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('value is too long'));
+
 			return false;
 		}
 
@@ -1224,22 +1284,41 @@ class CApiInputValidator {
 			return true;
 		}
 
-		$pattern = '/^(-?)0*(0|[1-9][0-9]*)(\.?[0-9]+)?(['.ZBX_BYTE_SUFFIXES.ZBX_TIME_SUFFIXES.'])?$/';
+		$number_parser = new CNumberParser(['with_suffix' => true]);
 
-		if (preg_match($pattern, strval($data)) !== 1) {
+		if ($number_parser->parse($data) != CParser::PARSE_SUCCESS) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is expected'));
+
 			return false;
 		}
 
-		$value = convertFunctionValue($data, ZBX_UNITS_ROUNDOFF_LOWER_LIMIT);
+		$value = $number_parser->calcValue();
 
-		if (bccomp($value, ZBX_MIN_INT64) < 0 || bccomp($value, ZBX_MAX_INT64) > 0) {
-			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is too large'));
-			return false;
+		if ($DB['DOUBLE_IEEE754']) {
+			if (abs($value) > ZBX_FLOAT_MAX) {
+				$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is too large'));
+
+				return false;
+			}
+		}
+		else {
+			if (abs($value) >= 1E+16) {
+				$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is too large'));
+
+				return false;
+			}
+			elseif ($value != round($value, 4)) {
+				$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number has too many fractional digits'));
+
+				return false;
+			}
 		}
 
-		// Trim leading zeroes.
-		$data = preg_replace($pattern, '${1}${2}${3}${4}', (string) $data);
+		// Remove leading zeros.
+		$data = preg_replace('/^(-)?(0+)?(\d.*)$/', '${1}${3}', $data);
+
+		// Add leading zero.
+		$data = preg_replace('/^(-)?(\..*)$/', '${1}0${2}', $data);
 
 		return true;
 	}
@@ -1444,6 +1523,7 @@ class CApiInputValidator {
 	 * Time unit validator like "10", "20s", "30m", "4h", "{$TIME}" etc.
 	 *
 	 * @param array  $rule
+	 * @param int    $rule['length'] (optional)
 	 * @param int    $rule['flags']  (optional) API_NOT_EMPTY, API_ALLOW_USER_MACRO, API_ALLOW_LLD_MACRO,
 	 *                                          API_TIME_UNIT_WITH_YEAR
 	 * @param int    $rule['in']     (optional)
@@ -1468,6 +1548,11 @@ class CApiInputValidator {
 			return false;
 		}
 
+		if (array_key_exists('length', $rule) && mb_strlen($data) > $rule['length']) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('value is too long'));
+			return false;
+		}
+
 		if (($flags & API_NOT_EMPTY) == 0 && $data === '') {
 			return true;
 		}
@@ -1490,7 +1575,7 @@ class CApiInputValidator {
 
 		$seconds = timeUnitToSeconds($data);
 
-		if (bccomp(ZBX_MIN_INT32, $seconds) > 0 || bccomp($seconds, ZBX_MAX_INT32) > 0) {
+		if ($seconds < ZBX_MIN_INT32 || $seconds > ZBX_MAX_INT32) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is too large'));
 			return false;
 		}
