@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 require_once dirname(__FILE__).'/js/configuration.template.list.js.php';
 
 $filter_tags = $data['filter']['tags'];
@@ -72,10 +76,24 @@ $filter
 	->setActiveTab($data['active_tab'])
 	->addFilterTab(_('Filter'), [
 		(new CFormList())
-			->addRow(_('Name'),
-				(new CTextBox('filter_name', $data['filter']['name']))
-					->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
-					->setAttribute('autofocus', 'autofocus')
+			->addRow(
+				(new CLabel(_('Host groups'), 'filter_groups__ms')),
+				(new CMultiSelect([
+					'name' => 'filter_groups[]',
+					'object_name' => 'hostGroup',
+					'data' => $data['filter']['groups'],
+					'popup' => [
+						'parameters' => [
+							'srctbl' => 'host_groups',
+							'srcfld1' => 'groupid',
+							'dstfrm' => $filter->getName(),
+							'dstfld1' => 'filter_groups_',
+							'templated_hosts' => 1,
+							'editable' => 1,
+							'enrich_parent_groups' => true
+						]
+					]
+				]))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 			)
 			->addRow(
 				(new CLabel(_('Linked templates'), 'filter_templates__ms')),
@@ -93,46 +111,43 @@ $filter
 						]
 					]
 				]))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+			)
+			->addRow(_('Name'),
+				(new CTextBox('filter_name', $data['filter']['name']))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 			),
 		(new CFormList())->addRow(_('Tags'), $filter_tags_table)
 	]);
 
 $widget = (new CWidget())
 	->setTitle(_('Templates'))
-	->setControls(new CList([
-		(new CForm('get'))
-			->cleanItems()
-			->setAttribute('aria-label', _('Main filter'))
-			->addItem((new CList())
-				->addItem([
-					new CLabel(_('Group'), 'groupid'),
-					(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-					$data['pageFilter']->getGroupsCB()
-				])
-			),
-		(new CTag('nav', true,
-			(new CList())
-				->addItem(new CRedirectButton(_('Create template'),
+	->setControls((new CTag('nav', true,
+		(new CList())
+			->addItem(new CRedirectButton(_('Create template'),
 				(new CUrl('templates.php'))
-					->setArgument('groupid', $data['pageFilter']->groupid)
+					->setArgument('groupids', array_keys($data['filter']['groups']))
 					->setArgument('form', 'create')
 					->getUrl()
-				))
-				->addItem(
-					(new CButton('form', _('Import')))->onClick('redirect("conf.import.php?rules_preset=template")')
 				)
+			)
+			->addItem(
+				(new CButton('form', _('Import')))->onClick('redirect("conf.import.php?rules_preset=template")')
+			)
 		))->setAttribute('aria-label', _('Content controls'))
-	]))
+	)
 	->addItem($filter);
 
 $form = (new CForm())->setName('templates');
 
+// create table
 $table = (new CTableInfo())
 	->setHeader([
 		(new CColHeader(
 			(new CCheckBox('all_templates'))->onClick("checkAll('".$form->getName()."', 'all_templates', 'templates');")
 		))->addClass(ZBX_STYLE_CELL_WIDTH),
-		make_sorting_header(_('Name'), 'name', $data['sortField'], $data['sortOrder']),
+		make_sorting_header(_('Name'), 'name', $data['sortField'], $data['sortOrder'],
+			(new CUrl('templates.php'))->getUrl()
+		),
+		_('Hosts'),
 		_('Applications'),
 		_('Items'),
 		_('Triggers'),
@@ -141,98 +156,90 @@ $table = (new CTableInfo())
 		_('Discovery'),
 		_('Web'),
 		_('Linked templates'),
-		_('Linked to'),
+		_('Linked to templates'),
 		_('Tags')
 	]);
 
 foreach ($data['templates'] as $template) {
-	$name = new CLink($template['name'],
-		'templates.php?form=update&templateid='.$template['templateid'].url_param('groupid')
-	);
+	$name = new CLink($template['name'], 'templates.php?form=update&templateid='.$template['templateid']);
 
-	$linkedTemplatesOutput = [];
-	$linkedToOutput = [];
+	$linked_templates_output = [];
+	$linked_to_output = [];
 
 	$i = 0;
-
-	order_result($template['parentTemplates'], 'name');
-
-	foreach ($template['parentTemplates'] as $parentTemplate) {
+	foreach ($template['parentTemplates'] as $parent_template) {
 		$i++;
 
 		if ($i > $data['config']['max_in_table']) {
-			$linkedTemplatesOutput[] = ' &hellip;';
+			$linked_templates_output[] = ' &hellip;';
 
 			break;
 		}
 
-		if ($linkedTemplatesOutput) {
-			$linkedTemplatesOutput[] = ', ';
+		if ($linked_templates_output) {
+			$linked_templates_output[] = ', ';
 		}
 
-		$url = 'templates.php?form=update&templateid='.$parentTemplate['templateid'].url_param('groupid');
+		$url = (new CUrl('templates.php'))
+			->setArgument('form', 'update')
+			->setArgument('templateid', $parent_template['templateid']);
 
-		if (array_key_exists($parentTemplate['templateid'], $data['writable_templates'])) {
-			$linkedTemplatesOutput[] = (new CLink($parentTemplate['name'], $url))
+		if (array_key_exists($parent_template['templateid'], $data['editable_templates'])) {
+			$linked_templates_output[] = (new CLink($parent_template['name'], $url))
 				->addClass(ZBX_STYLE_LINK_ALT)
 				->addClass(ZBX_STYLE_GREY);
 		}
 		else {
-			$linkedTemplatesOutput[] = (new CSpan($parentTemplate['name']))
+			$linked_templates_output[] = (new CSpan($parent_template['name']))
 				->addClass(ZBX_STYLE_GREY);
 		}
 	}
 
 	$i = 0;
-
-	$linkedToObjects = array_merge($template['hosts'], $template['templates']);
-	order_result($linkedToObjects, 'name');
-
-	foreach ($linkedToObjects as $linkedToObject) {
+	foreach ($template['templates'] as $child_template) {
 		$i++;
 
 		if ($i > $data['config']['max_in_table']) {
-			$linkedToOutput[] = ' &hellip;';
+			$linked_to_output[] = ' &hellip;';
 
 			break;
 		}
 
-		if ($linkedToOutput) {
-			$linkedToOutput[] = ', ';
+		if ($linked_to_output) {
+			$linked_to_output[] = ', ';
 		}
 
-		if ($linkedToObject['status'] == HOST_STATUS_TEMPLATE) {
-			if (array_key_exists($linkedToObject['templateid'], $data['writable_templates'])) {
-				$url = 'templates.php?form=update&templateid='.$linkedToObject['templateid'].url_param('groupid');
-				$link = (new CLink($linkedToObject['name'], $url))
-					->addClass(ZBX_STYLE_LINK_ALT)
-					->addClass(ZBX_STYLE_GREY);
-			}
-			else {
-				$link = (new CSpan($linkedToObject['name']))
-					->addClass(ZBX_STYLE_GREY);
-			}
+		if (array_key_exists($child_template['templateid'], $data['editable_templates'])) {
+			$url = (new CUrl('templates.php'))
+				->setArgument('form', 'update')
+				->setArgument('templateid', $child_template['templateid']);
+			$linked_to_output[] = (new CLink($child_template['name'], $url))
+				->addClass(ZBX_STYLE_LINK_ALT)
+				->addClass(ZBX_STYLE_GREY);
 		}
 		else {
-			if (array_key_exists($linkedToObject['hostid'], $data['writable_hosts'])) {
-				$url = 'hosts.php?form=update&hostid='.$linkedToObject['hostid'].url_param('groupid');
-				$link = (new CLink($linkedToObject['name'], $url))->addClass(ZBX_STYLE_LINK_ALT);
-			}
-			else {
-				$link = (new CSpan($linkedToObject['name']));
-			}
-
-			$link->addClass($linkedToObject['status'] == HOST_STATUS_MONITORED ? ZBX_STYLE_GREEN : ZBX_STYLE_RED);
+			$linked_to_output[] = (new CSpan($child_template['name']))
+				->addClass(ZBX_STYLE_GREY);
 		}
-
-		$linkedToOutput[] = $link;
 	}
 
 	$table->addRow([
 		new CCheckBox('templates['.$template['templateid'].']', $template['templateid']),
 		(new CCol($name))->addClass(ZBX_STYLE_NOWRAP),
 		[
-			new CLink(_('Applications'), 'applications.php?hostid='.$template['templateid'].url_param('groupid')),
+			new CLink(_('Hosts'),
+				(new CUrl('hosts.php'))
+					->setArgument('filter_set', '1')
+					->setArgument('filter_templates', [$template['templateid']])
+			),
+			CViewHelper::showNum(count(array_intersect_key($template['hosts'], $data['editable_hosts'])))
+		],
+		[
+			new CLink(_('Applications'),
+				(new CUrl('applications.php'))
+					->setArgument('filter_set', '1')
+					->setArgument('filter_hostids', [$template['templateid']])
+			),
 			CViewHelper::showNum($template['applications'])
 		],
 		[
@@ -252,7 +259,11 @@ foreach ($data['templates'] as $template) {
 			CViewHelper::showNum($template['triggers'])
 		],
 		[
-			new CLink(_('Graphs'), 'graphs.php?hostid='.$template['templateid'].url_param('groupid')),
+			new CLink(_('Graphs'),
+				(new CUrl('graphs.php'))
+					->setArgument('filter_set', '1')
+					->setArgument('filter_hostids', [$template['templateid']])
+			),
 			CViewHelper::showNum($template['graphs'])
 		],
 		[
@@ -260,15 +271,23 @@ foreach ($data['templates'] as $template) {
 			CViewHelper::showNum($template['screens'])
 		],
 		[
-			new CLink(_('Discovery'), 'host_discovery.php?hostid='.$template['templateid']),
+			new CLink(_('Discovery'),
+				(new CUrl('host_discovery.php'))
+					->setArgument('filter_set', '1')
+					->setArgument('filter_hostids', [$template['templateid']])
+			),
 			CViewHelper::showNum($template['discoveries'])
 		],
 		[
-			new CLink(_('Web'), 'httpconf.php?hostid='.$template['templateid'].url_param('groupid')),
+			new CLink(_('Web'),
+				(new CUrl('httpconf.php'))
+					->setArgument('filter_set', '1')
+					->setArgument('filter_hostids', [$template['templateid']])
+			),
 			CViewHelper::showNum($template['httpTests'])
 		],
-		$linkedTemplatesOutput,
-		$linkedToOutput,
+		$linked_templates_output,
+		$linked_to_output,
 		$data['tags'][$template['templateid']]
 	]);
 }
@@ -278,7 +297,14 @@ $form->addItem([
 	$data['paging'],
 	new CActionButtonList('action', 'templates',
 		[
-			'template.export' => ['name' => _('Export')],
+			'template.export' => ['name' => _('Export'), 'redirect' =>
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'export.templates.xml')
+					->setArgument('backurl', (new CUrl('templates.php'))
+						->setArgument('page', $data['page'] == 1 ? null : $data['page'])
+						->getUrl())
+					->getUrl()
+			],
 			'template.massupdateform' => ['name' => _('Mass update')],
 			'template.massdelete' => ['name' => _('Delete'), 'confirm' => _('Delete selected templates?')],
 			'template.massdeleteclear' => ['name' => _('Delete and clear'),
@@ -290,4 +316,4 @@ $form->addItem([
 
 $widget->addItem($form);
 
-return $widget;
+$widget->show();
