@@ -18,6 +18,11 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
+
+/**
+ * @var CView $this
+ */
+
 $pageHeader = (new CPageHeader(_('Warning').' ['._s('refreshed every %1$s sec.', 30).']'))
 	->addCssFile('assets/styles/'.CHtml::encode($data['theme']).'.css')
 	->display();
@@ -28,7 +33,11 @@ $buttons = array_key_exists('buttons', $data)
 
 echo '<body lang="'.CWebUser::getLang().'">';
 
-(new CTag('main', true, new CWarning($data['header'], $data['messages'], $buttons)))->show();
+(new CDiv((new CTag('main', true,
+	new CWarning($data['header'], $data['messages'], $buttons)
+))))
+	->addClass(ZBX_STYLE_LAYOUT_WRAPPER)
+	->show();
 
 echo get_js("setTimeout('document.location.reload();', 30000);");
 echo '</body>';
